@@ -321,6 +321,7 @@ module TZInfo
       linked_timezone 'Asia/Thimbu'
       timezone 'Asia/Thimphu'
       timezone 'Asia/Tokyo'
+      timezone 'Asia/Tomsk'
       linked_timezone 'Asia/Ujung_Pandang'
       timezone 'Asia/Ulaanbaatar'
       linked_timezone 'Asia/Ulan_Bator'
@@ -447,6 +448,7 @@ module TZInfo
       linked_timezone 'Europe/Jersey'
       timezone 'Europe/Kaliningrad'
       timezone 'Europe/Kiev'
+      timezone 'Europe/Kirov'
       timezone 'Europe/Lisbon'
       linked_timezone 'Europe/Ljubljana'
       timezone 'Europe/London'
